@@ -1,4 +1,6 @@
 import re
+from datetime import timedelta
+
 from django.core import mail
 from django.contrib.auth import get_user_model
 from django.test.utils import override_settings
@@ -427,12 +429,21 @@ class PasswordTests(APITestCase):
         self.assertEqual(len(mail.outbox), 1)
         self.assertEqual(mail.outbox[0].subject, 'Reset Your Password')
 
-        code = _get_code_from_email(mail)
+        code_not_used = _get_code_from_email(mail)
+
+        # Get a second code to use
+        url = reverse('authemail-password-reset')
+        payload = {
+            'email': self.em_user,
+        }
+        self.client.post(url, payload)
+        password_reset_code = PasswordResetCode.objects.latest('code')
+        code_used = password_reset_code.code
 
         # Send Password Reset Verify request
         url = reverse('authemail-password-reset-verify')
         params = {
-            'code': code,
+            'code': code_used,
         }
         response = self.client.get(url, params)
 
@@ -443,7 +454,7 @@ class PasswordTests(APITestCase):
         # Send Password Reset Verified request
         url = reverse('authemail-password-reset-verified')
         payload = {
-            'code': code,
+            'code': code_used,
             'password': self.pw_user_reset,
         }
         response = self.client.post(url, payload)
@@ -452,10 +463,41 @@ class PasswordTests(APITestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data['success'], 'Password reset.')
 
-        # Confirm password reset code can't be used again
+        # Confirm password reset code_not_used can't be used again
         url = reverse('authemail-password-reset-verify')
         params = {
-            'code': code,
+            'code': code_not_used,
+        }
+        response = self.client.get(url, params)
+
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+        self.assertEqual(response.data['detail'], 'Unable to verify user.')
+
+        # Confirm password reset code_used can't be used again
+        url = reverse('authemail-password-reset-verify')
+        params = {
+            'code': code_used,
+        }
+        response = self.client.get(url, params)
+
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+        self.assertEqual(response.data['detail'], 'Unable to verify user.')
+
+        # Get a third code to lapse
+        url = reverse('authemail-password-reset')
+        payload = {
+            'email': self.em_user,
+        }
+        self.client.post(url, payload)
+        password_reset_code = PasswordResetCode.objects.latest('code')
+        password_reset_code.created_at += timedelta(days=-(PasswordResetCode.objects.get_expiry_period()+1))
+        password_reset_code.save()
+        code_lapsed = password_reset_code.code
+
+        # Confirm password reset code_lapsed can't be used
+        url = reverse('authemail-password-reset-verify')
+        params = {
+            'code': code_lapsed,
         }
         response = self.client.get(url, params)
 
